@@ -5,7 +5,7 @@
 # SOAP::Lite is free software; you can redistribute it
 # and/or modify it under the same terms as Perl itself.
 #
-# $Id: Lite.pm 386 2011-08-18 19:48:31Z kutterma $
+# $Id: Lite.pm 414 2012-07-15 09:18:42Z kutterma $
 #
 # ======================================================================
 
@@ -14,7 +14,7 @@ package XML::Parser::Lite;
 use strict;
 use warnings;
 
-our $VERSION = 0.714;
+our $VERSION = 0.715;
 
 sub new {
     my $class = shift;
@@ -72,7 +72,8 @@ sub _regexp {
     my $TextSE = "[^<]+";
     my $UntilHyphen = "[^-]*-";
     my $Until2Hyphens = "([^-]*)-(?:[^-]$[^-]*-)*-";
-    my $CommentCE = "$Until2Hyphens(?{${package}::comment(\$2)})>?";
+    #my $CommentCE = "$Until2Hyphens(?{${package}::comment(\$2)})>?";
+    my $CommentCE = "(.+)--(?{${package}::comment(\$2)})>?";
 #    my $Until2Hyphens = "$UntilHyphen(?:[^-]$UntilHyphen)*-";
 #    my $CommentCE = "$Until2Hyphens>?";
     my $UntilRSBs = "[^\\]]*](?:[^\\]]+])*]+";
